<?php

namespace Kylin\GameData\Enums;

/**
 * 存档操作类型枚举
 */
enum SaveAction: string
{
    case Create = 'create';
    case Update = 'update';
    case ConflictResolve = 'conflict_resolve';
    case Delete = 'delete';

    public function label(): string
    {
        return match ($this) {
            self::Create => '创建',
            self::Update => '更新',
            self::ConflictResolve => '冲突解决',
            self::Delete => '删除',
        };
    }
}
