<?php

namespace Kylin\GameData\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * @method static \Kylin\GameData\Models\GameSave|null getSave(int $userId, int $gameId)
 * @method static \Kylin\GameData\Models\GameSave saveData(int $userId, int $gameId, array $data, int $version)
 * @method static bool deleteSave(int $userId, int $gameId)
 * @method static \Illuminate\Database\Eloquent\Collection getHistory(int $userId, int $gameId, int $limit = 20)
 */
class KylinGameData extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-game-data';
    }
}
