<?php

use Illuminate\Support\Facades\Route;
use Kylin\GameData\Http\Controllers\GameDataController;

Route::prefix('kylin/game-data')->middleware(['kylin.game', 'auth:sanctum'])->group(function () {
    // 获取游戏数据
    Route::get('/{appId}', [GameDataController::class, 'show']);

    // 同步游戏数据
    Route::post('/{appId}/sync', [GameDataController::class, 'sync']);

    // 存档历史
    Route::get('/{appId}/history', [GameDataController::class, 'history']);

    // 删除存档
    Route::delete('/{appId}', [GameDataController::class, 'destroy']);
});
